#include "firefox_plugin.h"

Firefox_plugin::Firefox_plugin()
{
#ifdef __arm__
    name = "epiphany-browser";
    icon = QIcon("/usr/share/pixmaps/chromium-browser.png");
#else
    name = "firefox";
    icon = QIcon("/usr/share/pixmaps/chromium-browser.png");
#endif
    genericName = "Web Page";
    if(QLocale::system().name() == "fr_FR"){genericName = "Page Web";}
}

QString Firefox_plugin::getName()
{
    return name;
}

QString Firefox_plugin::getGenericName()
{
    return genericName;
}

QIcon Firefox_plugin::getIcon()
{
    return icon;
}

QString Firefox_plugin::getCommand()
{
    return name + " " + command;
}

void Firefox_plugin::getPluginConfig(QVBoxLayout *info)
{
    chkUrl = new QCheckBox("Start with this URL or file :");
    if(QLocale::system().name() == "fr_FR"){chkUrl->setText("Commencer avec cette URL ou ce fichier :");}
    txtUrl = new QLineEdit();
    btnFile = new QPushButton();
    QHBoxLayout *layout = new QHBoxLayout();

    btnFile->setIcon(QIcon::fromTheme("folder"));
    connect(btnFile,SIGNAL(clicked()),this,SLOT(on_file_selected()));
    connect(chkUrl,SIGNAL(toggled(bool)),this,SLOT(on_chk_changed(bool)));
    layout->addWidget(chkUrl);
    layout->addWidget(txtUrl);
    layout->addWidget(btnFile);

    info->addLayout(layout);

    txtUrl->setText("http://linutop.com");
}

Plugin* Firefox_plugin::writeConfig()
{
    command = txtUrl->text();
    QString newFile = "[" + name + "]\n"
              "url=" + txtUrl->text() + "\n";
    if(chkUrl->isChecked())
        newFile += "withuri=1\n";
    else
        newFile += "withuri=0\n";
    newFile += "\n";
    QFile file(CONFFILE);
    if(file.open(QFile::ReadWrite |
                  QFile::Text))
    {
        bool keep = true;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "[" + name + "]")
              keep = false;
          if(keep)
              newFile += line + "\n";
          if(line == "")
              keep = true;

        }
        file.close();
        if(file.open(QFile::WriteOnly | QIODevice::Truncate |
                      QFile::Text))
        {
            QTextStream out(&file);
            out << newFile;
            file.flush();
            file.close();
        }
    }

    return this;
}

void Firefox_plugin::readConfig()
{
    QFile file(CONFFILE);
    if(file.open(QFile::ReadOnly |
                  QFile::Text))
    {
        bool parse = false;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "")
              parse = false;
          if(line == "[" + name + "]")
              parse = true;

          QStringList list = line.split("=");
          if((list.at(0) == "url") && parse)
          {
              txtUrl->setText(list.at(1));
          }
          if((list.at(0) == "withuri") && parse)
          {
              chkUrl->setChecked(list.at(1) == "1");
          }
        }
        file.close();
    }
    on_chk_changed(chkUrl->isChecked());
}

void Firefox_plugin::on_file_selected()
{
    QString fileName = QFileDialog::getOpenFileName(0,"Open file",QDir::homePath());
    if(fileName != "")
        txtUrl->setText(fileName);
}

void Firefox_plugin::on_chk_changed(bool state)
{
    btnFile->setEnabled(state);
    txtUrl->setEnabled(state);
}
