#include "mirage_plugin.h"

Mirage_plugin::Mirage_plugin()
{
    name = "mirage";
    genericName = "Photo Slideshow (Mirage)";
    icon = QIcon("/usr/share/pixmaps/mirage.png");
}

QString Mirage_plugin::getName()
{
    return name;
}

QString Mirage_plugin::getGenericName()
{
    return genericName;
}

QIcon Mirage_plugin::getIcon()
{
    return icon;
}

QString Mirage_plugin::getCommand()
{
    QString cmd = name + " -s";
    if(chkScreen->isChecked())
        cmd += " -f";
    return cmd + " " + command;
}

void Mirage_plugin::getPluginConfig(QVBoxLayout *info)
{
    lblPath = new QLabel("Select a folder :");
    txtPath = new QLineEdit();
    btnFile = new QPushButton();
    chkScreen = new QCheckBox("Play in full screen");
    lblNote = new QLabel("Note: You can set the interval to wait between each images in the Mirage preferences.");
    if(QLocale::system().name() == "fr_FR"){
        lblPath->setText("Sélectionner un fichier :");
        chkScreen->setText("Lancer en plein écran");
        lblNote->setText("Remarque: vous pouvez définir un intervalle d'attente entre chaque image dans les préférences de Mirage.");
    }
    QFont f( "Arial", 10);
    f.setItalic(true);
    lblNote->setFont(f);
    QHBoxLayout *layout = new QHBoxLayout();

    btnFile->setIcon(QIcon::fromTheme("folder"));
    connect(btnFile,SIGNAL(clicked()),this,SLOT(on_file_selected()));
    layout->addWidget(lblPath);
    layout->addWidget(txtPath);
    layout->addWidget(btnFile);

    info->addLayout(layout);
    info->addWidget(chkScreen);
    info->addWidget(lblNote);

    txtPath->setText("/home/linutop/Documents/photo");
    chkScreen->setChecked(true);
}

Plugin* Mirage_plugin::writeConfig()
{
    command = txtPath->text();
    QString newFile = "[" + name + "]\n"
              "path=" + txtPath->text() + "\n";
    if(chkScreen->isChecked())
        newFile += "fullscreen=1\n";
    else
        newFile += "fullscreen=0\n";
    newFile += "\n";

    QFile file(CONFFILE);
    if(file.open(QFile::ReadWrite |
                  QFile::Text))
    {
        bool keep = true;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "[" + name + "]")
              keep = false;
          if(keep)
              newFile += line + "\n";
          if(line == "")
              keep = true;

        }
        file.close();
        if(file.open(QFile::WriteOnly | QIODevice::Truncate |
                      QFile::Text))
        {
            QTextStream out(&file);
            out << newFile;
            file.flush();
            file.close();
        }
    }

    return this;
}

void Mirage_plugin::readConfig()
{
    QFile file(CONFFILE);
    if(file.open(QFile::ReadOnly |
                  QFile::Text))
    {
        bool parse = false;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "")
              parse = false;
          if(line == "[" + name + "]")
              parse = true;

          QStringList list = line.split("=");
          if((list.at(0) == "path") && parse)
          {
                txtPath->setText(list.at(1));
          }
          if((list.at(0) == "fullscreen") && parse)
          {
              chkScreen->setChecked(!(list.at(1) == "0"));
          }
        }
        file.close();
    }
}

void Mirage_plugin::on_file_selected()
{
    QString dir = QFileDialog::getExistingDirectory(0, tr("Open Directory"),QDir::homePath(),
                                                    QFileDialog::ShowDirsOnly
                                                    | QFileDialog::DontResolveSymlinks);
    if(dir != "")
        txtPath->setText(dir);
}
