#include "remote_plugin.h"

Remote_plugin::Remote_plugin()
{
    name = "remote";
    genericName = "Remote access (TSE, VNC)";
    if(QLocale::system().name() == "fr_FR"){genericName = "Accès à la télécommande";}
    icon = QIcon("/usr/share/pixmaps/tsclient.xpm");
}

QString Remote_plugin::getName()
{
    return name;
}

QString Remote_plugin::getGenericName()
{
    return genericName;
}

QIcon Remote_plugin::getIcon()
{
    return icon;
}

QString Remote_plugin::getCommand()
{
    QString cmd;
    if(RadioRDP->isChecked())
    {
        cmd = "rdesktop";
        if(chkScreen->isChecked())
            cmd += " -f";
        cmd += " -u " + txtUser->text() + " -p " + txtPass->text();
        if(txtOption->text() != "")
            cmd += " " + txtOption->text();
        cmd += " " + txtHost->text();
    }
    else
    {
        cmd = "vncviewer";
        if(chkScreen->isChecked())
            cmd += " -fullscreen";
        cmd += " -user " + txtUser->text();
        if(txtOption->text() != "")
            cmd += " " + txtOption->text();
        cmd += " " + txtHost->text();
    }
    return cmd;

}

void Remote_plugin::getPluginConfig(QVBoxLayout *info)
{
    lblDesc = new QLabel("This plugin will start a connection to a remote system.");

    lblRadio = new QLabel("Protocol :");
    RadioVNC = new QRadioButton("VNC");
    RadioRDP = new QRadioButton("RDP");

    QHBoxLayout *layout = new QHBoxLayout();
    layout->addWidget(lblRadio);
    layout->addWidget(RadioVNC);
    layout->addWidget(RadioRDP);

    chkScreen = new QCheckBox("Fullscreen");

    QHBoxLayout *layoutHost = new QHBoxLayout();
    QLabel *lblHost = new QLabel("Host :");
    txtHost = new QLineEdit();
    txtHost->setMaximumWidth(200);
    layoutHost->setContentsMargins(0,0,170,0);
    layoutHost->addWidget(lblHost);
    layoutHost->addWidget(txtHost);

    QHBoxLayout *layoutUser = new QHBoxLayout();
    QLabel *lblUser = new QLabel("User :");
    txtUser = new QLineEdit();
    txtUser->setMaximumWidth(200);
    layoutUser->setContentsMargins(0,0,170,0);
    layoutUser->addWidget(lblUser);
    layoutUser->addWidget(txtUser);

    QHBoxLayout *layoutPass = new QHBoxLayout();
    QLabel *lblPass = new QLabel("Password :");
    txtPass = new QLineEdit();
    txtPass->setEchoMode(QLineEdit::Password);
    txtPass->setMaximumWidth(200);
    layoutPass->setContentsMargins(0,0,170,0);
    layoutPass->addWidget(lblPass);
    layoutPass->addWidget(txtPass);

    QHBoxLayout *layoutOption = new QHBoxLayout();
    QLabel *lblOption = new QLabel("Extra options :");
    txtOption = new QLineEdit();
    txtOption->setMaximumWidth(200);
    layoutOption->setContentsMargins(0,0,170,0);
    layoutOption->addWidget(lblOption);
    layoutOption->addWidget(txtOption);

    info->addWidget(lblDesc);
    info->addLayout(layout);
    info->addWidget(chkScreen);
    info->addLayout(layoutHost);
    info->addLayout(layoutUser);
    info->addLayout(layoutPass);
    info->addLayout(layoutOption);

    if(QLocale::system().name() == "fr_FR"){
        lblDesc->setText("Ce plugin va démarrer une connexion à un système distant.");
        lblRadio->setText("Protocole :");
        chkScreen->setText("Plein écran");
    }

    connect(RadioRDP,SIGNAL(toggled(bool)),this,SLOT(on_chk_changed(bool)));
}

Plugin* Remote_plugin::writeConfig()
{
    QString newFile = "[" + name + "]\n";
    if(RadioRDP->isChecked())
        newFile += "proto=0\n";
    else
        newFile += "proto=1\n";

    newFile += "host=" + txtHost->text() + "\n";
    newFile += "user=" + txtUser->text() + "\n";
    newFile += "passwd=" + txtPass->text() + "\n";
    newFile += "extra=" + txtOption->text() + "\n";

    if(chkScreen->isChecked())
        newFile += "fullscreen=true\n";
    else
        newFile += "fullscreen=false\n";
    newFile += "\n";
    QFile file(CONFFILE);
    if(file.open(QFile::ReadWrite |
                  QFile::Text))
    {
        bool keep = true;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "[" + name + "]")
              keep = false;
          if(keep)
              newFile += line + "\n";
          if(line == "")
              keep = true;

        }
        file.close();
        if(file.open(QFile::WriteOnly | QIODevice::Truncate |
                      QFile::Text))
        {
            QTextStream out(&file);
            out << newFile;
            file.flush();
            file.close();
        }
    }
    return this;
}

void Remote_plugin::readConfig()
{
    QFile file(CONFFILE);
    if(file.open(QFile::ReadOnly |
                  QFile::Text))
    {
        bool parse = false;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "")
              parse = false;
          if(line == "[" + name + "]")
              parse = true;

          QStringList list = line.split("=");
          if((list.at(0) == "proto") && parse)
          {
              if(list.at(1) == "1")
                  RadioVNC->setChecked(true);
              else
                  RadioRDP->setChecked(true);

          }
          if((list.at(0) == "host") && parse)
          {
              txtHost->setText(list.at(1));
          }
          if((list.at(0) == "user") && parse)
          {
              txtUser->setText(list.at(1));
          }
          if((list.at(0) == "passwd") && parse)
          {
              txtPass->setText(list.at(1));
          }
          if((list.at(0) == "extra") && parse)
          {
              txtOption->setText(list.at(1));
          }
          if((list.at(0) == "fullscreen") && parse)
          {
              chkScreen->setChecked(list.at(1) == "true");
          }
        }
        file.close();
    }
    on_chk_changed(RadioRDP->isChecked());
}

void Remote_plugin::on_chk_changed(bool state)
{
    txtPass->setEnabled(state);
}
