#include "vlc_plugin.h"

Vlc_plugin::Vlc_plugin()
{
    name = "vlc";
    genericName = "Audio/Video/DVD";
    icon = QIcon("/usr/share/icons/hicolor/48x48/apps/vlc.png");
}

QString Vlc_plugin::getName()
{
    return name;
}

QString Vlc_plugin::getGenericName()
{
    return genericName;
}

QIcon Vlc_plugin::getIcon()
{
    return icon;
}

QString Vlc_plugin::getCommand()
{
    QString cmd = name;
    if(chkScreen->isChecked())
        cmd += " -f";
    if(chkLoop->isChecked())
        cmd += " -L";
    return cmd + " " + command;
}

void Vlc_plugin::getPluginConfig(QVBoxLayout *info)
{
    lblPath = new QLabel("Select a file or a playlist :");
    txtPath = new QLineEdit();
    btnFile = new QPushButton();
    chkLoop = new QCheckBox("Loop");
    chkScreen = new QCheckBox("Start in full screen");
    QHBoxLayout *layout = new QHBoxLayout();

    btnFile->setIcon(QIcon::fromTheme("folder"));
    connect(btnFile,SIGNAL(clicked()),this,SLOT(on_file_selected()));
    layout->addWidget(lblPath);
    layout->addWidget(txtPath);
    layout->addWidget(btnFile);

    info->addLayout(layout);
    info->addWidget(chkScreen);
    info->addWidget(chkLoop);

    txtPath->setText("/cdrom/video/linutopdemo.avi");
    chkScreen->setChecked(true);
    chkLoop->setChecked(true);

    if(QLocale::system().name() == "fr_FR"){
        lblPath->setText("Sélectionnez un fichier ou une playlist :");
        chkLoop->setText("Boucle");
        chkScreen->setText("Plein écran");
    }
}

Plugin* Vlc_plugin::writeConfig()
{
    command = txtPath->text();
    QString newFile = "[" + name + "]\n"
              "path=" + txtPath->text() + "\n";
    if(chkScreen->isChecked())
        newFile += "fullscreen=1\n";
    else
        newFile += "fullscreen=0\n";
    if(chkLoop->isChecked())
        newFile += "loop=1\n";
    else
        newFile += "loop=0\n";
    newFile += "\n";

    QFile file(CONFFILE);
    if(file.open(QFile::ReadWrite |
                  QFile::Text))
    {
        bool keep = true;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "[" + name + "]")
              keep = false;
          if(keep)
              newFile += line + "\n";
          if(line == "")
              keep = true;

        }
        file.close();
        if(file.open(QFile::WriteOnly | QIODevice::Truncate |
                      QFile::Text))
        {
            QTextStream out(&file);
            out << newFile;
            file.flush();
            file.close();
        }
    }

    return this;
}

void Vlc_plugin::readConfig()
{
    QFile file(CONFFILE);
    if(file.open(QFile::ReadOnly |
                  QFile::Text))
    {
        bool parse = false;
        QTextStream in(&file);
        while (!in.atEnd())
        {
          QString line = in.readLine();
          if(line == "")
              parse = false;
          if(line == "[" + name + "]")
              parse = true;

          QStringList list = line.split("=");
          if((list.at(0) == "path") && parse)
          {
              txtPath->setText(list.at(1));
          }
          if((list.at(0) == "fullscreen") && parse)
          {
              chkScreen->setChecked(!(list.at(1) == "0"));
          }
          if((list.at(0) == "loop") && parse)
          {
              chkLoop->setChecked(!(list.at(1) == "0"));
          }
        }
        file.close();
    }
}

void Vlc_plugin::on_file_selected()
{
    QString fileName = QFileDialog::getOpenFileName(0,"Open file",QDir::homePath());
    if(fileName != "")
        txtPath->setText(fileName);
}
